*   SCGEHSF: A simple Static UK CGE model with health effects
*   Specific Factors (here skilled labour and capital in health care)

*   By Martine Rutten

$offlisting
$include data.gms

Parameter
va(i)         Elasticity of substitution between factors of production
GCMult(i)     Government consumption multiplier
Eta0          Non participation rate if health care does not affect WL
Fbar          Fixed endowment of factor f by household h
SFbar         Fixed endowment of sector-specific factor by household h
Upsilon(i,f)  Share parameter health composite
Epsilon(f)    Waiting list elasticity;

va("1")  = 0.2;
va("2")  = 1.3;
va("3")  = 1.3;
va("4")  = 1.3;
va("5")  = 1.3;
va("6")  = 1.4;
va("7")  = 1.7;
va("8")  = 1.3;
va("9")  = 1.3;
va("10") = 1.3;
va("11") = 1.3;

GCMult(i)    = 1;

Epsilon(f)   = 2;
Eta0("skill")= 0.0289;
Eta0("unsk") = 0.0434;

Upsilon("NHS","Unsk") = 0.960;
Upsilon("NHS","Skill")= 0.834;
Upsilon("PHC","Unsk") = 1-Upsilon("NHS","Unsk") ;
Upsilon("PHC","Skill")= 1-Upsilon("NHS","Skill");

* Introduce sector-specific factor: share of factor f in sector i immobile
Parameter FSHARE(f,i) Share of sector-specific factor in factor use sector;
FSHARE(f,i)            = 0   ;
* doctors and nurses in health care are immobile (85%)
FSHARE("skill","10")   = 0.85;

* 90% of capital (buildings) in health care are immobile
FSHARE("cap","10")     = 0.90;

* Adjust endowments households accordingly
Fbar(h,f)    = SAM(h,f);
SFbar(h,f,i) = (Fbar(h,f)/sum(g,Fbar(g,f)))*FSHARE(f,i)*Use(f,i)/(1+ETAX0(f));
Fbar(h,f)    = Fbar(h,f)-sum(i, SFbar(h,f,i));
Fbar(h,f)    = Fbar(h,f)*1/(1-Eta0(f))       ;
SFbar(h,f,i) = SFbar(h,f,i)*1/(1-Eta0(f))    ;

* Adjust factor use in production accordingly
Parameter Mfactor(f,i) Use of mobile factor by sector
          Sfactor(f,i) Use of sector-specific factor;
Sfactor(f,i) = Use(f,i)*FSHARE(f,i)/(1+ETAX0(f))    ;
Mfactor(f,i) = Use(f,i)*(1-FSHARE(f,i))/(1+ETAX0(f));

$if not "%system.incparent%"=="" option sysout=off; option solprint=off;

$ontext
$model:SCGE
$sectors:
         X(i)           ! production of sector i
         CET(i)         ! armington aggregate demand (domestic and export)
         ST             ! total (real) savings
         M(i)$VM(i)     ! imports of commodity i
         E(i)$VE(i)     ! exports of commodity i
$commodities:
         PQ(i)          ! producer price commodity i
         PD(i)          ! domestic consumption price commodity i
         PE(i)$VE(i)    ! export price commodity i
         PM(i)$VM(i)    ! import price commodity i
         PF(f)                   ! price of factor f
         PFS(f,i)$fshare(f,i)    ! sector specific factors
         PS                      ! price of savings
         ER             ! exchange rate (price of foreign exchange)
         PYG            ! price of artificial commodity 'real tax income'
         PTR            ! price of artificial commodity transfer
$consumers:
         YG             ! government income
         TR             ! transfers to households
         Y(h)           ! household income
$auxiliary:
         GOVCONS(i)$(USE(i,"GOVT"))    ! Real government consumption
         HC(f)                         ! Health composite
         EPR(f)                        ! Effective participation rate

$prod:X(i)       s:0  t:1  va:va(i)
      O:PQ(j)    Q:Make(j,i)     A:YG T:PTAX(i) P:(1-PTAX0(i))
      I:PF(f)    Q:Mfactor(f,i)  A:YG T:ETAX(f) P:(1+ETAX0(f))  va:
      I:PFS(f,i) Q:Sfactor(f,i)  A:YG T:ETAX(f) P:(1+ETAX0(f))  va:
      I:PD(j)    Q:Use(j,i)

$prod:CET(i)     s:0  t:2  arm:2
      O:PD(i)    Q:VD(i)         A:YG  T:CTAX(i) P:(VDN(i)/VD(i))
      O:PE(i)    Q:VE(i)
      I:PQ(i)    Q:(sum(j, Make(i,j))) arm:
      I:PM(i)    Q:VM(i)               arm:
      I:PD("7")  Q:Make(i,"Margin")

$prod:ST         s:0
      O:PS       Q:(sum(i,Use(i,"inv")))
      I:PD(i)    Q:Use(i,"inv")

$prod:M(i)$VM(i)
      O:PM(i)    Q:VM(i)
      I:ER       Q:VM(i)

$prod:E(i)$VE(i)
      O:ER       Q:VE(i)
      I:PE(i)    Q:VE(i)

$demand:YG
      D:PYG     Q:SAM("gov","tax")

$demand:TR                   s:1
      E:PYG                  Q:(Mult*SAM("gov","tax"))
      E:PD(i)$Use(i,"GOVT")  Q:(-Mult*Use(i,"GOVT"))     R:GOVCONS(i)
      D:PTR                  Q:(sum(h,SAM(h,"gov")))
      E:ER                   Q:(Mult*(SAM("gov","row")-SAM("row","gov")))

$demand:Y(h)                 s:1
      E:PF(f)                Q:(Mult*Fbar(h,f))          R:EPR(f)
      E:PFS(f,i)             Q:(Mult*SFbar(h,f,i))       R:EPR(f)
      D:PD(i)                Q:Use(i,h)
      D:PS                   Q:SAM("inv",h)
      E:PTR                  Q:(Mult*SAM(h,"gov"))

$report:
      V:U(h)     W:Y(h)
      V:FD(f,i)  I:PF(f)         prod:X(i)
      V:SFD(f,i) I:PFS(f,i)      prod:X(i)
      V:N(j,i)   I:PD(j)         prod:X(i)
      V:QS(i)    I:PQ(i)         prod:CET(i)
      V:QTM(i)   I:PD("7")       prod:CET(i)
      V:INV(i)   I:PD(i)         prod:ST
      V:C(i,h)   D:PD(i)         demand:Y(h)
      V:S(h)     D:PS            demand:Y(h)

$constraint:GOVCONS(i)$Use(i,"GOVT")
         GOVCONS(i) =E= GCMult(i) * ER/PD(i) + 1$(GCMult(i)=0);
$constraint:HC(f)
         HC(f)      =E= prod[i, (CET(i)/Mult)**Upsilon(i,f)];
$constraint:EPR(f)
         EPR(f)     =E= 1-Eta0(f)/(HC(f)**Epsilon(f));
$offtext
$sysinclude mpsgeset SCGE

* check benchmark replication:
SCGE.ITERLIM = 0        ;
HC.L(f)      = 1        ;
EPR.L(f)     = 1-Eta0(f);
GOVCONS.L(i) = 1        ;
ER.FX        = 1        ;
$include SCGE.GEN
solve SCGE using mcp;
abort$(SCGE.OBJVAL > 1e-3) "benchmark replication failed", SCGE.OBJVAL;

$libinclude store these X CET ST M E PQ PD PE PM PF PS ER YG TR Y
$libinclude store these GOVCONS HC EPR U PFS FD SFD N QS QTM INV C S

$libinclude store calc utility (h)  = u.l(h)*[sum[i,Use(i,h)]+Sam('inv',h)];
$libinclude store calc Welfare = sum[h,utility(h)] + GOVCONS.L("NHS")*Use("NHS","govt");
$libinclude store calc WelfareEx    = sum[h,utility(h)];

Parameter alphaG(h) Share of household h in public health care provisioning;

alphaG("HSE1") = 0.251;
alphaG("HSE2") = 0.087;
alphaG("HSE3") = 0.076;
alphaG("HSE4") = 0.306;
alphaG("HSE5") = 0.280;

$libinclude store calc Utility1 (h) = Utility(h) + alphaG(h)*GOVCONS.L("NHS")*Use("NHS","govt");
$libinclude store calc EVPUB (h) = Utility1(h) - Utility(h);
$libinclude store calc EVPUBTOT = sum(h, EVPUB(h));

$libinclude store calc YHF (h,f) = PF.l(f)*Fbar(h,f)*EPR.l(f);
* YHFS (income household from specific factors)
$libinclude store calc YHFS (h,f,i) = PFS.l(f,i)*SFbar(h,f,i)*EPR.l(f);
$libinclude store calc YHTR (h)  = PTR.l* SAM(h,"gov");

$libinclude store calc FE (h,f) = Fbar(h,f)*EPR.l(f)  ;
$libinclude store calc WL (h,f) = Fbar(h,f)-FE(h,f)   ;
$libinclude store calc eta (f)  = 1-EPR.l(f)          ;

* store SFE (effective endowment specific factor), SWL (its waiting list),
$libinclude store calc SFE (h,f,i) = SFbar(h,f,i)*EPR.l(f)  ;
$libinclude store calc SWL (h,f,i) = SFbar(h,f,i)-SFE(h,f,i);

$libinclude store calc GEXP (i) = GOVCONS.L(i)*Use(i,"govt")*PD.l(i);

* Trade measures
$libinclude store calc TRADE  = sum(i, PE.l(i)*E.l(i)*VE(i));
$libinclude store calc TRADE1 = sum(i, PM.l(i)*M.l(i)*VM(i));
$libinclude store calc TRADESH = sum(i, PE.l(i)*E.l(i)*VE(i))/sum(h,sum(f,YHF(h,f)));
$libinclude store calc TRADESH1 = sum(i, PM.l(i)*M.l(i)*VM(i))/sum(h,sum(f,YHF(h,f)));

$libinclude store setmodel SCGE
$libinclude store base
$libinclude store setbase base

* numeraire check:
SCGE.ITERLIM = 1000;
ER.FX        = 1.5;
$include SCGE.GEN
solve SCGE using mcp;
abort$(abs(ST.l-1) > 1e-5) "numeraire check failed", SCGE.OBJVAL;

* homegeneity check:
ER.FX = 1;
MULT  = 2;
$include SCGE.GEN
solve SCGE using mcp;
abort$(abs(PS.l-1) > 1e-5) "homegeneity check failed", SCGE.OBJVAL;
MULT  = 1;

$if not "%system.incparent%"=="" $goto end

* test an increase in health expenditure, govt exp all goods i fixed in value
GCMult("NHS")       = 1.1131;
$batinclude solve exp2
GCMult("NHS")       = 1;

$libinclude store display changes percent

$label end