* This file defines all sets (sectors or activities, households,
* factors of production), multiplier to check for homogeneity and
* performs calculations on data put in HealthSAM.dat:
*       scaling (all values in MPSGE represent billions)
*       calculation of ad valorem tax rates
*       reformatting health expenditures into NHS and PHC

* By Martine Rutten

$offlisting


$include healthsam.dat
Sets a  all activities/
1       Primary
2       Pharmaceuticals
3       Medical instruments
4       Other manufacturing
5       Energy
6       Construction
7       Distribution and transport
8       Finance
9       Public administration and defence
10      Health care
11      Other services
NHS     Dummy sector for National Health Service
PHC     Dummy sector for private health consumption
SKILL   Skilled labour
UNSK    Unskilled labour
CAP     Capital (operating surplus)
TAX     Net taxation on products
HSE1    Pensioners
HSE2    Non-working with children
HSE3    Non-working without children
HSE4    Working with children
HSE5    Working without children
INV     Investment
GOVT    Government
EXPORT  Exports
MARGIN  Margins
IMPORT  Imports
/;
alias(a,b);

set i   sectors and commodities/
1       Primary
2       Pharmaceuticals
3       Medical instruments
4       Other manufacturing
5       Energy
6       Construction
7       Distribution and transport
8       Finance
9       Public administration and defense
10      Health care
11      Other services
NHS     Dummy sector for National Health Service
PHC     Dummy sector for private health consumption
/;
alias (i,j);

set f   factors of production/
skill   Skilled labour
unsk    Unskilled labour
CAP     Capital (operating surplus)
/;
alias (f,d);
set h   households/
HSE1    Pensioners
HSE2    Non-working with children
HSE3    Non-working without children
HSE4    Working with children
HSE5    Working without children
/;
alias(h,g);

* Reformat health expenditures (NHS and PHC)
*       NHS buys health care from the health sector and sells it to the government
*       PHC buys health care from the health sector and sells it to households

Use("10","NHS")   = Use("10","GOVT");
Use("NHS","GOVT") = Use("10","GOVT");
Use("10","GOVT")  = 0;

Use("10","PHC")   = sum[h, Use("10",h)];
Use("PHC",h)      = Use("10",h);
Use("10",h)       = 0;

Make("NHS","NHS") = Use("NHS","GOVT");
Make("PHC","PHC") = sum[h, Use("PHC",h)];

Display Use,Make;

* Scaling: (SCALE can be declared previously, otherwise default of 1,000)
$if not declared Scale Scalar Scale /1E3/;
Use(a,b) = Use(a,b) / Scale;
Make(a,b)=Make(a,b) / Scale;
alias(*,all1,all2);
sam(all1,all2) = sam(all1,all2) / Scale;

* Calculation ad valorem tax rates:
*       output taxe(ctax,ptax) are net tax, so producers receive (1-taxrate)* market price
*       input tax (etax) defined as gross tax, so producers pay  (1+taxrate)* market price

Parameters
CTAX    consumption tax
PTAX    production tax
ETAX    employment tax

CTAX0,PTAX0,ETAX0;

PTAX(j)$sum[a, USE(a,j)] = USE("TAX",j) / sum[a, USE(a,j)];
PTAX0(j)= PTAX(j);

ETAX(f)$sum[h, SAM(h,f)] = SAM("tax",f) / sum[h, SAM(h,f)];
ETAX0(f) = ETAX(f);

Parameters
VE      Value of exports
VM      Value of imports
VD      Value of domestic demand including consumption tax
VDN     Value of domestic demand excluding consumption tax;

VE(i)  = Use(i,"EXPORT")          ;
VM(i)  = Make(i,"IMPORT")         ;
VD(i)  = sum[a, Make(i,a)] - VE(i);
VDN(i) = VD(i) - MAKE(i,"TAX")    ;

CTAX(i)$VD(i) = 1 - VDN(i)/VD(i);
CTAX0(i)      = CTAX(i)         ;

display PTAX,ETAX,CTAX;

Scalar  Mult Check homogeneity of model /1/;